<?php

/*
 * admin.class.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class Admin
{
	public function is_permitted($page)
	{
		$class['user'] = new User;
		$class['config'] = new Config;
		
		$admin = unserialize($class['config']->admin);
		$privileges = $this->role_get_info('admin', $class['user']->user_get_info('role'));
		
		if ($privileges != 'all')
		{
			foreach ($admin as $key => $value)
				if (in_array($page, explode(',', $value[1])) && in_array($key, explode(',', $privileges)))
					return TRUE;
		}
		else
		{
			foreach ($admin as $key => $value)
				if (in_array($page, explode(',', $value[1])))
					return TRUE;
		}
		
		return FALSE;
	}
	
	public function is_admin($user = NULL)
	{
		global $db;
		
		$user = (!empty($user)) ? $user : $_SESSION['_user'];
		$result = $db->select('users', array('admin'), array('user' => '=\'' . $db->escape($user) . '\'', 'AND', 'admin' => '=\'1\''));
		
		return ($user = $db->fetch_assoc($result)) ? TRUE : FALSE;		
	}
	
	public function check_session()
	{
		if ($this->is_authorized() === FALSE)
		{
			header('Location: login.php');
			exit;
		}
	}
	
	public function is_authorized()
	{
		$class['user'] = new User;
		
		if ($class['user']->is_authorized())
			return $this->is_admin() ? TRUE : FALSE;
		
		return FALSE;
	}
	
	public function role_get_info($field = '*', $id)
	{
		global $db;
		
		$result = $db->select('roles', $field, array('id' => '=\'' . $db->escape($id) . '\''));
		if ($role = $db->fetch_assoc($result))
			return ($field == '*' || strpos($field, ',') !== FALSE) ? $role : $role[$field];
	}
	
	public function theme_is_compatible($theme)
	{
		$class['file'] = new File;
		$class['config'] = new Config;
		
		$version = $class['file']->get_version('../themes/' . $theme . '/' . $theme . '.info');
		$star = strpos(strtolower($version), '*');
		
		if (empty($star))
			return ($version === $class['config']->version) ? TRUE : FALSE;
		else
		{
			$version = substr($version, 0, $star);
			$limny = substr($class['config']->version, 0, $star);
			
			return ($version === $limny) ? TRUE : FALSE;
		}
	}
	
	public function reset_users_theme($theme)
	{
		global $db;
		
		$ids = array();
		
		$result = $db->select('users', array('id'), array('theme' => '=\'' . $db->escape($theme) . '\''));
		while ($user = $db->fetch_assoc($result))
			array_push($ids, $user['id']);
		
		foreach ($ids as $id)
			$db->update('users', array('theme' => '\'\''), array('id' => '=\'' . $db->escape($id) . '\''));
	}
	
	public function theme_get_info($theme)
	{
		$file = file_get_contents('../themes/' . $theme . '/' . $theme . '.info');
		
		$data = explode("\r\n\r\n", $file);
		$data = $data[1];
		$line = explode("\n", $data);
		$info = array();
		
		for ($i = 0; $i < count($line); $i++)
		{
			if (empty($line[$i]) === FALSE)
			{
				$item = explode('=', $line[$i]);
				$info[trim($item[0])] = trim($item[1]);
			}
		}
		
		return $info;
	}
	
	public function installed_themes()
	{
		global $db;
		
		$themes = array();
		
		$result = $db->select('themes', array('name'));
		while ($theme = $db->fetch_assoc($result))
			array_push($themes, $theme['name']);
		
		return $themes;
	}
	
	public function themes_list()
	{
		$themes = array();
		
		$dir = opendir('../themes');
		while ($theme = readdir($dir))
			if (in_array($theme, array('.', '..')) === FALSE && is_dir('../themes/' . $theme))
				array_push($themes, $theme);
		
		closedir($dir);
		
		return $themes;
	}
	
	public function get_app($app, $field = '*')
	{
		global $db;
		
		$result = $db->select('apps', $field, array('name' => '=\'' . $db->escape($app) . '\''));
		if ($app = $db->fetch_assoc($result))
			return ($field == '*' || strpos($field, ',') === TRUE) ? $app : $app[$field];
	}
	
	public function app_get_info($app)
	{
		$file = file_get_contents('../apps/' . $app . '/' . $app . '.info');
		
		$line = explode("\n", $file);
		$info = array();
		
		for ($i = 2; $i < count($line); $i++)
		{
			if (empty($line[$i]) === FALSE)
			{
				$item = explode('=', $line[$i]);
				$info[trim($item[0])] = trim($item[1]);
			}
		}
		
		return $info;
	}
	
	public function installed_apps()
	{
		global $db;
		
		$apps = array();
		
		$result = $db->select('apps', array('name'), array('1=1', 'ORDER BY', 'id' => ''));
		while ($app = $db->fetch_assoc($result))
			array_push($apps, $app['name']);
		
		return $apps;
	}
	
	public function add_image($theme, $name, $pattern, $values, $image, $default = NULL)
	{
		global $db;
		
		if (is_array($values))
		{
			$values = serialize($values);
			$default = $values;
		}
		
		$db->insert('images', array('theme' => $db->escape($theme), 'name' => $db->escape($name), 'pattern' => $db->escape($pattern), 'values' => $db->escape($values), 'image' => $db->escape($image), 'default' => $db->escape($default))); 
	}
	
	public function add_style($theme, $name, $type, $value)
	{
		global $db;
		
		$db->insert('styles', array('theme' => $db->escape($theme), 'name' => $db->escape($name), 'type' => $db->escape($type), 'value' => $db->escape($value), 'default' => $db->escape($value)));
	}
	
	public function add_pattern($name, $variables, $function)
	{
		global $db;
		
		$variables = serialize($variables);
		$db->insert('patterns', array('theme' => $db->escape($name), 'variables' => $db->escape($variables), 'function' => $db->escape($function)));
	}
	
	public function remove_theme($theme)
	{
		global $db;
		
		$db->delete('images', array('theme' => '=\'' . $db->escape($theme) . '\''));
		$db->delete('styles', array('theme' => '=\'' . $db->escape($theme) . '\''));
	}
	
	public function load_language($app)
	{
		$class['language'] = new Language;
		
		$langs_path = '../apps/' . $app . '/admin/langs';
		
		$default = $langs_path . '/en.php';
		$system = $langs_path . '/' . $class['language']->language . '.php';
		
		if (file_exists($system))
		{
			include_once $system;
			return TRUE;
		}
		else if (file_exists($default))
		{
			include_once $default;
			return TRUE;
		}
		
		return FALSE;
	}
}

?>