<?php

/*
 * image.class.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class Image
{
	public $file;
	
	private $image;
	
	public function resize($width = NULL, $height = NULL)
	{
		if (empty($width) && empty($height))
			return FALSE;
		
		$extension = explode('.', $this->file);
		$extension = strtolower(end($extension));
		
		list($old_width, $old_height) = getimagesize($this->file);
		
		switch ($extension)
		{
			case 'jpeg': $old_image = imagecreatefromjpeg($this->file); break;
			case 'gif': $old_image = imagecreatefromgif($this->file); break;
			case 'jpg': $old_image = imagecreatefromjpeg($this->file); break;
			case 'png': $old_image = imagecreatefrompng($this->file); break;
		}
		
		if (empty($width) || $width <= 0)
			$width = ($height * $old_width) / $old_height;
		else if (empty($height) || $width <= 0)
			$height = ($width * $old_height) / $old_width;
		
		$image = imagecreatetruecolor($width, $height);
		
		if ($extension == 'png')
		{
			imagealphablending($image, FALSE);
			$trans_color = imagecolorallocatealpha($image, 0, 0, 0, 127);
			imagefill($image, 0, 0, $trans_color);
			imagesavealpha($image, TRUE);
		}
		
		imagecopyresampled($image, $old_image, 0, 0, 0, 0, $width, $height, $old_width, $old_height);
		
		$this->image = $image;
	}
	
	public function save($file)
	{
		$extension = explode('.', $file);
		$extension = strtolower(end($extension));
		
		switch ($extension)
		{
			case 'jpeg': imagejpeg($this->image, $file); break;
			case 'gif': imagegif($this->image, $file); break;
			case 'jpg': imagejpeg($this->image, $file); break;
			case 'png': imagepng($this->image, $file); break;
		}
	}
	
	public function destroy()
	{
		$this->file = NULL;
		imagedestroy($this->image);
	}
}

?>