<?php

/*
 * postgresql.class.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class PostgreSQL
{
	public $connection;
	public $tbl_prfx = '';
	public $classifier = '"';
	
	public function connect($hostname, $username, $password, $database)
	{
		$connection = @pg_connect('host=' . $hostname . ' port=5432 dbname=' . $database . ' user=' . $username . ' password=' . $password);
		$this->connection = $connection;
		
		return $connection;
	}
	
	public function close()
	{
		return pg_close($this->connection);
	}
	
	public function query($query)
	{
		return pg_query($this->connection, $query);
	}
	
	public function select($table, $columns, $expression = NULL)
	{
		$query = 'SELECT ';
		
		if (is_array($columns))
		{
			foreach ($columns as $value)
				$query .= '"' . $value . '",';
			
			$query = substr($query, 0, strlen($query) - 1);
		}
		else
			$query .= $columns;
		
		$query .= ' FROM "' . $this->tbl_prfx . $table . '"';
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function insert($table, $values)
	{
		$query = 'INSERT INTO "' . $this->tbl_prfx . $table . '" (';
		
		$keys = '';
		$vals = '';
		
		foreach ($values as $key => $value)
		{
			$keys .= '"' . $key . '",';
			$vals .= is_null($value) ? 'NULL,' : '\'' . $value . '\',';
		}
		
		$query .= substr($keys, 0, strlen($keys) - 1) . ') VALUES (' . substr($vals, 0, strlen($vals) - 1) . ')';
		
		return $this->query($query);
	}
	
	public function update($table, $values, $expression = NULL)
	{
		$query = 'UPDATE "' . $this->tbl_prfx . $table . '" SET ';
		
		foreach ($values as $key => $value)
		{
			$query .= '"' . $key . '"=';
			$query .= is_null($value) ? 'NULL,' : $value . ',';
		}
		
		$query = substr($query, 0, strlen($query) - 1);
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function delete($table, $expression = NULL)
	{
		$query = 'DELETE FROM "' . $this->tbl_prfx . $table . '"';
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function create_table($table, $columns, $auto_increment_column = NULL, $additions = NULL)
	{
		$query = 'CREATE TABLE "' . $this->tbl_prfx . $table . '" (';
		
		if (empty($auto_increment_column) === FALSE)
			pg_exec('CREATE SEQUENCE "' . $this->tbl_prfx . $table . '_' . $auto_increment_column . '_seq"');
		
		foreach ($columns as $key => $value)
			$query .= '"' . $key . '" ' . $value . (empty($auto_increment_column) === FALSE && $key == $auto_increment_column ? ' PRIMARY KEY DEFAULT nextval(\'' . $this->tbl_prfx . $table . '_' . $auto_increment_column . '_seq\')' : NULL) . ',';
		
		$query = substr($query, 0, strlen($query) - 1) . ')';
		$query = $this->query($query);
		
		return $query;
	}
	
	public function drop_table($table, $auto_increment_column = NULL)
	{
		$query = 'DROP TABLE "' . $this->tbl_prfx . $table . '"';
		$query = $this->query($query);
		$exec = pg_exec('DROP SEQUENCE IF EXISTS "' . $this->tbl_prfx . $table . '_' . (empty($auto_increment_column) ? 'id' : $auto_increment_column) . '_seq"');
		
		return $query;
	}
	
	public function fetch_row($result)
	{
		return pg_fetch_row($result);
	}
	
	public function fetch_assoc($result)
	{
		return pg_fetch_assoc($result);
	}
	
	public function fetch_array($result)
	{
		return pg_fetch_array($result, NULL, PGSQL_BOTH);
	}
	
	public function num_rows($result)
	{
		return pg_num_rows($result);
	}
	
	public function num_fields($result)
	{
		return pg_num_fields($result);
	}
	
	public function parse_expr($expression)
	{
		if (is_array($expression))
		{
			$result = ' WHERE ';
			
			foreach ($expression as $key => $value)
				$result .= is_numeric($key) ? $value . ' ' : '"' . $key . '"' . $value . ' ';
			
			$result = substr($result, 0, strlen($result) - 1);
		}
		else
			$result = ' ' . $expression;
		
		return $result;
	}
	
	public function escape($str, $internal = FALSE)
	{
		if (get_magic_quotes_gpc() && $internal === FALSE)
			$str = stripslashes($str);
		
		return pg_escape_string($this->connection, $str);
	}
}

?>