<?php

/*
 * sqlite3.class.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

class SQLiteThree
{
	public $connection;
	public $tbl_prfx = '';
	public $classifier = '"';
	
	public function open($database)
	{
		$connection = new SQLite3($database);
		$this->connection = $connection;
		
		return $connection;
	}
	
	public function close()
	{
		return $this->connection->close();
	}
	
	public function query($query)
	{
		return $this->connection->query($query);
	}
	
	public function select($table, $columns, $expression = NULL)
	{
		$query = 'SELECT ';
		
		if (is_array($columns))
		{
			foreach ($columns as $value)
				$query .= '"' . $value . '",';
			
			$query = substr($query, 0, strlen($query) - 1);
		}
		else
			$query .= $columns;
		
		$query .= ' FROM \'' . $this->tbl_prfx . $table . '\'';
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function insert($table, $values)
	{
		$columns = array();
		$result = $this->query('PRAGMA table_info(\'' . $this->tbl_prfx . $table . '\')');
		while ($row = $this->fetch_row($result))
			$columns[$row[1]] = $row[2];
		
		$query = 'INSERT INTO \'' . $this->tbl_prfx . $table . '\' VALUES (';
		
		foreach ($columns as $key => $value)
			$query .= isset($values[$key]) ? '\'' . $values[$key] . '\',' : 'NULL,';
		
		$query = substr($query, 0, strlen($query) - 1) . ')';
		
		return $this->query($query);
	}
	
	public function update($table, $values, $expression = NULL)
	{
		$query = 'UPDATE \'' . $this->tbl_prfx . $table . '\' SET ';
		
		foreach ($values as $key => $value)
		{
			$query .= '"' . $key . '"=';
			$query .= is_null($value) ? 'NULL,' : $value . ',';
		}
		$query = substr($query, 0, strlen($query) - 1);
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function delete($table, $expression = NULL)
	{
		$query = 'DELETE FROM \'' . $this->tbl_prfx . $table . '\'';
		
		if (empty($expression) === FALSE)
			$query .= $this->parse_expr($expression);
		
		return $this->query($query);
	}
	
	public function create_table($table, $columns, $auto_increment_column = NULL, $additions = NULL)
	{
		$query = 'CREATE TABLE \'' . $this->tbl_prfx . $table . '\' (';
		
		foreach ($columns as $key => $value)
			$query .= '"' . $key . '" ' . (empty($auto_increment_column) === FALSE && $key == $auto_increment_column ? 'INTEGER NOT NULL PRIMARY KEY' : $value) . ',';
		
		$query = substr($query, 0, strlen($query) - 1) . ')';
		
		return $this->query($query);
	}
	
	public function drop_table($table, $auto_increment_column = NULL)
	{
		$query = 'DROP TABLE \'' . $this->tbl_prfx . $table . '\'';
		
		return $this->query($query);
	}
	
	public function fetch_row($result)
	{
		return $result->fetchArray(SQLITE3_NUM);
	}
	
	public function fetch_assoc($result)
	{
		return $result->fetchArray(SQLITE3_ASSOC);
	}
	
	public function fetch_array($result)
	{
		return $result->fetchArray(SQLITE3_BOTH);
	}
	
	public function num_rows($result)
	{
		$i = 0;
		while ($row = $result->fetchArray(SQLITE3_NUM))
			$i++;
		
		return $i;
	}
	
	public function num_fields($result)
	{
		return $result->numColumns();
	}
	
	public function parse_expr($expression)
	{
		if (is_array($expression))
		{
			$result = ' WHERE ';
			
			foreach ($expression as $key => $value)
				$result .= is_numeric($key) ? $value . ' ' : '"' . $key . '"' . $value . ' ';
			
			$result = substr($result, 0, strlen($result) - 1);
		}
		else
			$result = ' ' . $expression;
		
		return $result;
	}
	
	public function escape($str, $internal = FALSE)
	{
		if (get_magic_quotes_gpc() && $internal === FALSE)
			$str = stripslashes($str);
		
		return $this->connection->escapeString($str);
	}
}

?>