<?php

/*
 * init.php
 *
 * @copyright     Copyright 2009-2012 Hamid Reza Samak
 * @link          http://www.limny.org
 * @package       limny
 * @author        Hamid Reza Samak <hamid@limny.org>
 * @license       GNU/GPL License (http://www.gnu.org/licenses/gpl.html)
 */

define('__PATH__', str_replace('\\', '/', dirname(__FILE__)));

require_once __PATH__ . '/config.php';
require_once __PATH__ . '/incs/functions.php';

if (isset($config) === FALSE)
	limny_error('It seems Limny is not installed yet. Click <a href="' . base_path() . '/install/install.php">here</a> to install it.');

require_once __PATH__ . '/incs/' . $config['dbs_type'] . '.class.php';

switch ($config['dbs_type'])
{
	default:
		limny_error('Database type not found');
	break;
	
	case 'mysql':
		$db = new MySQL;
		
		$db->connect($config['hostname'], $config['username'], $config['password']) || limny_error('Cannot connect MySQL server');
		$db->tbl_prfx = $config['tbl_prfx'];
		$db->select_db($config['database']) || limny_error('Cannot connect to MySQL database');
	break;
	
	case 'postgresql':
		$db = new PostgreSQL;
		
		$db->connect($config['hostname'], $config['username'], $config['password'], $config['database']) || limny_error('Cannot connect PostgreSQL database');
		$db->tbl_prfx = $config['tbl_prfx'];
	break;
	
	case 'sqlite':
		$db = new SQLite;
		
		if (file_exists(__PATH__ . '/' . $config['database']))
			$db->open(__PATH__ . '/' . $config['database']);
		else
			limny_error('Cannot open SQLite database file');
		
		$db->tbl_prfx = $config['tbl_prfx'];
	break;
	
	case 'sqlite3';
		$db = new SQLiteThree;
		
		if (file_exists(__PATH__ . '/' . $config['database']))
			$db->open(__PATH__ . '/' . $config['database']);
		else
			limny_error('Cannot open SQLite 3 database file');
		
		$db->tbl_prfx = $config['tbl_prfx'];
	break;
}

if (file_exists(__PATH__ . '/install'))
	limny_error('Connection to database established but it\'s not all.<br /><ul><li>If you are already installed Limny, <u>delete `install` directory</u> then refresh this page.</li><li>If you are not installed it, do it now <a href="' . base_path() . '/install/install.php">here</a></li></ul><br /><b>Note:</b> Installation directory existence considers a security risk after installation.');

?>